BSize

Struct BSize 

pub struct BSize<T: Unsigned>(pub T);
Byte size representation.

Tuple Fields

0: T

Implementations

Source

impl BSize<u8>

pub fn display(self) -> Display

Returns a display wrapper.

Source

impl BSize<u16>

pub fn display(self) -> Display

Returns a display wrapper.

Source

impl BSize<u32>

pub fn display(self) -> Display

Returns a display wrapper.

Source

impl BSize<u64>

pub fn display(self) -> Display

Returns a display wrapper.

Source

impl BSize<usize>

pub fn display(self) -> Display

Returns a display wrapper.

Source

impl<T: Unsigned> BSize<T>

pub fn with(self, f: impl FnOnce(T) -> T) -> Self

Calculate a new byte size with the provided function, returning a new struct.

pub const fn b(size: T) -> Self

Constructs a byte size wrapper from a quantity of bytes.

Source

impl BSize<u16>

pub const fn kb(size: u16) -> Self

Constructs a byte size wrapper from a quantity of kb units.

pub const fn kib(size: u16) -> Self

Constructs a byte size wrapper from a quantity of kib units.

Source

impl BSize<u32>

pub const fn kb(size: u32) -> Self

Constructs a byte size wrapper from a quantity of kb units.

pub const fn kib(size: u32) -> Self

Constructs a byte size wrapper from a quantity of kib units.

pub const fn mb(size: u32) -> Self

Constructs a byte size wrapper from a quantity of mb units.

pub const fn mib(size: u32) -> Self

Constructs a byte size wrapper from a quantity of mib units.

pub const fn gb(size: u32) -> Self

Constructs a byte size wrapper from a quantity of gb units.

pub const fn gib(size: u32) -> Self

Constructs a byte size wrapper from a quantity of gib units.

Source

impl BSize<u64>

pub const fn kb(size: u64) -> Self

Constructs a byte size wrapper from a quantity of kb units.

pub const fn kib(size: u64) -> Self

Constructs a byte size wrapper from a quantity of kib units.

pub const fn mb(size: u64) -> Self

Constructs a byte size wrapper from a quantity of mb units.

pub const fn mib(size: u64) -> Self

Constructs a byte size wrapper from a quantity of mib units.

pub const fn gb(size: u64) -> Self

Constructs a byte size wrapper from a quantity of gb units.

pub const fn gib(size: u64) -> Self

Constructs a byte size wrapper from a quantity of gib units.

pub const fn tb(size: u64) -> Self

Constructs a byte size wrapper from a quantity of tb units.

pub const fn tib(size: u64) -> Self

Constructs a byte size wrapper from a quantity of tib units.

pub const fn pb(size: u64) -> Self

Constructs a byte size wrapper from a quantity of pb units.

pub const fn pib(size: u64) -> Self

Constructs a byte size wrapper from a quantity of pib units.

pub const fn eb(size: u64) -> Self

Constructs a byte size wrapper from a quantity of eb units.

pub const fn eib(size: u64) -> Self

Constructs a byte size wrapper from a quantity of eib units.

Source

impl BSize<usize>

pub const fn kb(size: usize) -> Self

Constructs a byte size wrapper from a quantity of kb units.

pub const fn kib(size: usize) -> Self

Constructs a byte size wrapper from a quantity of kib units.

Source

impl BSize<usize>

pub const fn mb(size: usize) -> Self

Constructs a byte size wrapper from a quantity of mb units.

pub const fn mib(size: usize) -> Self

Constructs a byte size wrapper from a quantity of mib units.

pub const fn gb(size: usize) -> Self

Constructs a byte size wrapper from a quantity of gb units.

pub const fn gib(size: usize) -> Self

Constructs a byte size wrapper from a quantity of gib units.

Source

impl BSize<usize>

pub const fn tb(size: usize) -> Self

Constructs a byte size wrapper from a quantity of tb units.

pub const fn tib(size: usize) -> Self

Constructs a byte size wrapper from a quantity of tib units.

pub const fn pb(size: usize) -> Self

Constructs a byte size wrapper from a quantity of pb units.

pub const fn pib(size: usize) -> Self

Constructs a byte size wrapper from a quantity of pib units.

pub const fn eb(size: usize) -> Self

Constructs a byte size wrapper from a quantity of eb units.

pub const fn eib(size: usize) -> Self

Constructs a byte size wrapper from a quantity of eib units.

Source

impl BSize<u16>

pub fn as_kb(&self) -> f64

Returns byte count as kilobytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_kib(&self) -> f64

Returns byte count as kibibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

Source

impl BSize<u32>

pub fn as_kb(&self) -> f64

Returns byte count as kilobytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_kib(&self) -> f64

Returns byte count as kibibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_mb(&self) -> f64

Returns byte count as megabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_mib(&self) -> f64

Returns byte count as mebibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_gb(&self) -> f64

Returns byte count as gigabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_gib(&self) -> f64

Returns byte count as gibibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

Source

impl BSize<u64>

pub fn as_kb(&self) -> f64

Returns byte count as kilobytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_kib(&self) -> f64

Returns byte count as kibibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_mb(&self) -> f64

Returns byte count as megabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_mib(&self) -> f64

Returns byte count as mebibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_gb(&self) -> f64

Returns byte count as gigabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_gib(&self) -> f64

Returns byte count as gibibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_tb(&self) -> f64

Returns byte count as terabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_tib(&self) -> f64

Returns byte count as tebibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_pb(&self) -> f64

Returns byte count as petabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_pib(&self) -> f64

Returns byte count as pebibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_eb(&self) -> f64

Returns byte count as exabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_eib(&self) -> f64

Returns byte count as exbibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

Source

impl BSize<usize>

pub fn as_kb(&self) -> f64

Returns byte count as kilobytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_kib(&self) -> f64

Returns byte count as kibibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

Source

impl BSize<usize>

pub fn as_mb(&self) -> f64

Returns byte count as megabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_mib(&self) -> f64

Returns byte count as mebibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_gb(&self) -> f64

Returns byte count as gigabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_gib(&self) -> f64

Returns byte count as gibibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

Source

impl BSize<usize>

pub fn as_tb(&self) -> f64

Returns byte count as terabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_tib(&self) -> f64

Returns byte count as tebibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_pb(&self) -> f64

Returns byte count as petabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_pib(&self) -> f64

Returns byte count as pebibytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_eb(&self) -> f64

Returns byte count as exabytes.

The result is approximate when the byte count cannot be represented exactly as f64.

pub fn as_eib(&self) -> f64

Returns byte count as exbibytes.

The result is approximate when the byte count cannot be represented exactly as f64.